@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2024 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -47,11 +47,10 @@ static SDL_bool send_backgrounding_pending = SDL_FALSE;
 static SDL_bool send_foregrounding_pending = SDL_FALSE;
 #endif
 
-static void
-SDL_HandleSIG(int sig)
+static void SDL_HandleSIG(int sig)
 {
     /* Reset the signal handler */
-    signal(sig, SDL_HandleSIG);
+    (void)signal(sig, SDL_HandleSIG);
 
     /* Send a quit event next time the event loop pumps. */
     /* We can't send it in signal handler; SDL_malloc() might be interrupted! */
@@ -59,54 +58,52 @@ SDL_HandleSIG(int sig)
         send_quit_pending = SDL_TRUE;
     }
 
-    #ifdef SDL_BACKGROUNDING_SIGNAL
+#ifdef SDL_BACKGROUNDING_SIGNAL
     else if (sig == SDL_BACKGROUNDING_SIGNAL) {
         send_backgrounding_pending = SDL_TRUE;
     }
-    #endif
+#endif
 
-    #ifdef SDL_FOREGROUNDING_SIGNAL
+#ifdef SDL_FOREGROUNDING_SIGNAL
     else if (sig == SDL_FOREGROUNDING_SIGNAL) {
         send_foregrounding_pending = SDL_TRUE;
     }
-    #endif
+#endif
 }
 
-static void
-SDL_EventSignal_Init(const int sig)
+static void SDL_EventSignal_Init(const int sig)
 {
 #ifdef HAVE_SIGACTION
     struct sigaction action;
 
     sigaction(sig, NULL, &action);
 #ifdef HAVE_SA_SIGACTION
-    if ( action.sa_handler == SIG_DFL && (void (*)(int))action.sa_sigaction == SIG_DFL ) {
+    if (action.sa_handler == SIG_DFL && (void (*)(int))action.sa_sigaction == SIG_DFL) {
 #else
-    if ( action.sa_handler == SIG_DFL ) {
+    if (action.sa_handler == SIG_DFL) {
 #endif
         action.sa_handler = SDL_HandleSIG;
         sigaction(sig, &action, NULL);
     }
-#elif HAVE_SIGNAL_H
-    void (*ohandler) (int) = signal(sig, SDL_HandleSIG);
+#elif defined(HAVE_SIGNAL_H)
+    void (*ohandler)(int) = signal(sig, SDL_HandleSIG);
     if (ohandler != SIG_DFL) {
         signal(sig, ohandler);
     }
 #endif
 }
 
-static void
-SDL_EventSignal_Quit(const int sig)
+static void SDL_EventSignal_Quit(const int sig)
 {
 #ifdef HAVE_SIGACTION
     struct sigaction action;
     sigaction(sig, NULL, &action);
-    if ( action.sa_handler == SDL_HandleSIG ) {
+    if (action.sa_handler == SDL_HandleSIG) {
         action.sa_handler = SIG_DFL;
         sigaction(sig, &action, NULL);
     }
-#elif HAVE_SIGNAL_H
-    void (*ohandler) (int) = signal(sig, SIG_DFL);
+#elif defined(HAVE_SIGNAL_H)
+    void (*ohandler)(int) = signal(sig, SIG_DFL);
     if (ohandler != SDL_HandleSIG) {
         signal(sig, ohandler);
     }
@@ -114,44 +111,41 @@ SDL_EventSignal_Quit(const int sig)
 }
 
 /* Public functions */
-static int
-SDL_QuitInit_Internal(void)
+static int SDL_QuitInit_Internal(void)
 {
     /* Both SIGINT and SIGTERM are translated into quit interrupts */
     /* and SDL can be built to simulate iOS/Android semantics with arbitrary signals. */
     SDL_EventSignal_Init(SIGINT);
     SDL_EventSignal_Init(SIGTERM);
 
-    #ifdef SDL_BACKGROUNDING_SIGNAL
+#ifdef SDL_BACKGROUNDING_SIGNAL
     SDL_EventSignal_Init(SDL_BACKGROUNDING_SIGNAL);
-    #endif
+#endif
 
-    #ifdef SDL_FOREGROUNDING_SIGNAL
+#ifdef SDL_FOREGROUNDING_SIGNAL
     SDL_EventSignal_Init(SDL_FOREGROUNDING_SIGNAL);
-    #endif
+#endif
 
     /* That's it! */
     return 0;
 }
 
-static void
-SDL_QuitQuit_Internal(void)
+static void SDL_QuitQuit_Internal(void)
 {
     SDL_EventSignal_Quit(SIGINT);
     SDL_EventSignal_Quit(SIGTERM);
 
-    #ifdef SDL_BACKGROUNDING_SIGNAL
+#ifdef SDL_BACKGROUNDING_SIGNAL
     SDL_EventSignal_Quit(SDL_BACKGROUNDING_SIGNAL);
-    #endif
+#endif
 
-    #ifdef SDL_FOREGROUNDING_SIGNAL
+#ifdef SDL_FOREGROUNDING_SIGNAL
     SDL_EventSignal_Quit(SDL_FOREGROUNDING_SIGNAL);
-    #endif
+#endif
 }
 #endif
 
-int
-SDL_QuitInit(void)
+int SDL_QuitInit(void)
 {
 #ifdef HAVE_SIGNAL_SUPPORT
     if (!SDL_GetHintBoolean(SDL_HINT_NO_SIGNAL_HANDLERS, SDL_FALSE)) {
@@ -161,8 +155,7 @@ SDL_QuitInit(void)
     return 0;
 }
 
-void
-SDL_QuitQuit(void)
+void SDL_QuitQuit(void)
 {
 #ifdef HAVE_SIGNAL_SUPPORT
     if (!disable_signals) {
@@ -171,8 +164,7 @@ SDL_QuitQuit(void)
 #endif
 }
 
-void
-SDL_SendPendingSignalEvents(void)
+void SDL_SendPendingSignalEvents(void)
 {
 #ifdef HAVE_SIGNAL_SUPPORT
     if (send_quit_pending) {
@@ -180,25 +172,24 @@ SDL_SendPendingSignalEvents(void)
         SDL_assert(!send_quit_pending);
     }
 
-    #ifdef SDL_BACKGROUNDING_SIGNAL
+#ifdef SDL_BACKGROUNDING_SIGNAL
     if (send_backgrounding_pending) {
         send_backgrounding_pending = SDL_FALSE;
         SDL_OnApplicationWillResignActive();
     }
-    #endif
+#endif
 
-    #ifdef SDL_FOREGROUNDING_SIGNAL
+#ifdef SDL_FOREGROUNDING_SIGNAL
     if (send_foregrounding_pending) {
         send_foregrounding_pending = SDL_FALSE;
         SDL_OnApplicationDidBecomeActive();
     }
-    #endif
+#endif
 #endif
 }
 
 /* This function returns 1 if it's okay to close the application window */
-int
-SDL_SendQuit(void)
+int SDL_SendQuit(void)
 {
 #ifdef HAVE_SIGNAL_SUPPORT
     send_quit_pending = SDL_FALSE;
